View source: R/download-asymsam.R
| download_asymsam_monthly | R Documentation |
Deprecated. The upstream API for the Asymmetric and Symmetric SAM
indices is no longer available. These functions now return NULL with a
warning.
download_asymsam_monthly(use_cache = FALSE, file = NULL)
download_asymsam_daily(use_cache = FALSE, file = NULL)
use_cache |
logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'. |
file |
optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk. |
NULL (invisibly). A warning is issued.
Campitelli, E., Diaz, L. B., & Vera, C. (2022). Assessment of zonally symmetric and asymmetric components of the Southern Annular Mode using a novel approach. Climate Dynamics, 58(1), 161-178. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s00382-021-05896-5")}
## Not run:
asymsam <- download_asymsam_monthly()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.